;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "ekg" "20251018.2337"
  "A system for recording and linking information."
  '((triples "0.6.1")
    (emacs   "28.1")
    (llm     "0.18.0"))
  :url "https://github.com/ahyatt/ekg"
  :commit "088284818903eaec3815627041f7ec2140be65f7"
  :revdesc "088284818903"
  :keywords '("outlines" "hypermedia")
  :authors '(("Andrew Hyatt" . "ahyatt@gmail.com"))
  :maintainers '(("Andrew Hyatt" . "ahyatt@gmail.com")))
